@@ -1,7 +1,6 @@
 from extra_views.advanced import (
     CreateWithInlinesView,
     FormSetSuccessMessageMixin,
-    InlineFormSet,
     InlineFormSetFactory,
     NamedFormsetsMixin,
     SuccessMessageMixin,
@@ -10,19 +9,16 @@ from extra_views.advanced import (
 from extra_views.contrib.mixins import SearchableListMixin, SortableListMixin
 from extra_views.dates import CalendarMonthView
 from extra_views.formsets import (
-    BaseFormSetMixin,
-    BaseInlineFormSetMixin,
     FormSetView,
     InlineFormSetView,
     ModelFormSetView,
 )
 
-__version__ = "0.13.0"
+__version__ = "0.14.0"
 
 __all__ = [
     "CreateWithInlinesView",
     "FormSetSuccessMessageMixin",
-    "InlineFormSet",
     "InlineFormSetFactory",
     "NamedFormsetsMixin",
     "SuccessMessageMixin",
@@ -30,8 +26,6 @@ __all__ = [
     "SearchableListMixin",
     "SortableListMixin",
     "CalendarMonthView",
-    "BaseFormSetMixin",
-    "BaseInlineFormSetMixin",
     "FormSetView",
     "InlineFormSetView",
     "ModelFormSetView",
