@@ -24,19 +24,6 @@ class BaseGenericInlineFormSetFactory(BaseInlineFormSetFactory):
         return result
 
 
-class BaseGenericInlineFormSetMixin(BaseGenericInlineFormSetFactory):
-    def __init__(self, *args, **kwargs):
-        from warnings import warn
-
-        warn(
-            "`extra_views.BaseGenericInlineFormSetMixin` has been renamed to "
-            "`BaseGenericInlineFormSetFactory`. `BaseGenericInlineFormSetMixin` "
-            "will be removed in a future release.",
-            DeprecationWarning,
-        )
-        super(BaseGenericInlineFormSetMixin, self).__init__(*args, **kwargs)
-
-
 class GenericInlineFormSetFactory(BaseGenericInlineFormSetFactory):
     """
     Class used to create a `GenericInlineFormSet` from `generic_inlineformset_factory`
@@ -55,19 +42,6 @@ class GenericInlineFormSetFactory(BaseGenericInlineFormSetFactory):
         self.view = view
 
 
-class GenericInlineFormSet(GenericInlineFormSetFactory):
-    def __init__(self, *args, **kwargs):
-        from warnings import warn
-
-        warn(
-            "`extra_views.GenericInlineFormSet` has been renamed to "
-            "`GenericInlineFormSetFactory`. `GenericInlineFormSet` "
-            "will be removed in a future release.",
-            DeprecationWarning,
-        )
-        super(GenericInlineFormSet, self).__init__(*args, **kwargs)
-
-
 class GenericInlineFormSetMixin(BaseGenericInlineFormSetFactory, InlineFormSetMixin):
     """
     A mixin that provides a way to show and handle a generic inline formset in a
