@@ -13,11 +13,11 @@ COUNTRY_CHOICES = (
 
 class AddressFormSet(BaseFormSet):
     def add_fields(self, form, index):
-        super(AddressFormSet, self).add_fields(form, index)
+        super().add_fields(form, index)
         form.fields["county"] = forms.ChoiceField(choices=COUNTRY_CHOICES, initial="gb")
 
 
 class BaseArticleFormSet(BaseModelFormSet):
     def add_fields(self, form, index):
-        super(BaseArticleFormSet, self).add_fields(form, index)
+        super().add_fields(form, index)
         form.fields["notes"] = forms.CharField(initial="Write notes here")
